local frame = nil
local cycle = 0
local horiz, vert = 64, 40 -- must be multiples of 4, should match aspect ratio of the display for best results

local function DisplayGridPattern()
	cycle = cycle + 1 -- alternate between no grid, big grid, small grid
	if cycle == 3 then cycle = 0 end
	if frame then frame:Hide(); frame = nil end

	if cycle > 0 then -- display either red or green grid
		frame = CreateFrame('Frame', nil, UIParent) 
		frame:SetAllPoints(UIParent)
		local w = GetScreenWidth() / horiz
		local r, g = 0, 1
		if cycle == 2 then r = 1; g = 0 end
		for i = 0, horiz do
			local t = frame:CreateTexture(nil, 'BACKGROUND')
			if i == (horiz / 2) then t:SetTexture(0, 1, 1, 0.5) else t:SetTexture(r, g, 0, 0.25) end
			t:SetPoint('TOPLEFT', frame, 'TOPLEFT', i * w - 0.5, 0)
			t:SetPoint('BOTTOMRIGHT', frame, 'BOTTOMLEFT', i * w + 0.5, 0)
		end
		local h = GetScreenHeight() / vert
		for i = 0, vert do
			local t = frame:CreateTexture(nil, 'BACKGROUND')
			if i == (vert / 2) then t:SetTexture(0, 1, 1, 0.5) else t:SetTexture(r, g, 0, 0.25) end
			t:SetPoint('TOPLEFT', frame, 'TOPLEFT', 0, -i * h + 0.5)
			t:SetPoint('BOTTOMRIGHT', frame, 'TOPRIGHT', 0, -i * h - 0.5)
		end	
	end
end

LibStub:GetLibrary("LibDataBroker-1.1"):NewDataObject("Switcher", {
	type = "launcher",
	text = "Switcher",
	OnClick = function(_, msg)
		if msg == "LeftButton" then
			if IsShiftKeyDown() then
				local maxMode = 1 - GetCVar("gxMaximize")
				SetCVar("gxMaximize", maxMode)
				SetCVar("gxWindow", 1)
			else
				local screenMode = 1 - GetCVar("gxWindow")
				SetCVar("gxMaximize", 0)
				SetCVar("gxWindow", screenMode)
			end
			GameTooltip:Hide()
			RestartGx()
			GameTooltip:Show()
		elseif msg == "RightButton" then
			if IsShiftKeyDown() then DisplayGridPattern() else
				GameTooltip:Hide()
				Screenshot()
				GameTooltip:Show()
			end
		end
	end,
	icon = "Interface\\Icons\\Spell_Arcane_TeleportThunderBluff",
	OnTooltipShow = function(tooltip)
		if GetCVar("gxWindow") == "1" then
			if GetCVar("gxMaximize") == "1" then
				tooltip:AddDoubleLine("Switcher", "Windowed (Full Screen)")
			else
				tooltip:AddDoubleLine("Switcher", "Windowed")
			end
		else
			tooltip:AddDoubleLine("Switcher", "Full Screen")
		end
		tooltip:AddLine("|cffffff00" .. "Left-click|r to toggle between full screen and windowed")
		tooltip:AddLine("|cffffff00" .. "Shift-left-click|r select windowed (full screen)")
		tooltip:AddLine("|cffffff00" .. "Right-click|r to take a screenshot")
		tooltip:AddLine("|cffffff00" .. "Shift-right-click|r to toggle display grid overlay")
		tooltip:Show()
	end,
})